@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include "config.h"
@@ -97,7 +97,9 @@ gpk_session_logout (GpkSession *session)
 	}
 
 	/* we have to use no reply, as the SM calls into g-p-m to get the can_suspend property */
-	dbus_g_proxy_call_no_reply (session->priv->proxy, "Shutdown", G_TYPE_INVALID);
+	dbus_g_proxy_call_no_reply (session->priv->proxy, "Logout",
+				    G_TYPE_UINT, 1, /* no confirmation, but use inhibitors */
+				    G_TYPE_INVALID);
 	return TRUE;
 }
 
